@@ -1,7 +1,7 @@
 from importlib import import_module
 from pprint import pformat
-from datetime import datetime
 
+from datetime import datetime
 from floraconcierge import errors
 
 
@@ -40,6 +40,17 @@ class Object(object):
         if '_className' in kwargs:
             del kwargs['_className']
 
+        for k, v in kwargs.iteritems():
+            try:
+                v = int(v)
+            except (ValueError, TypeError):
+                try:
+                    v = float(v)
+                except (ValueError, TypeError):
+                    pass
+
+            kwargs[k] = v
+
         self.__dict__.update(kwargs)
 
     def __repr__(self):
